@@ -5,6 +5,7 @@ from types import ModuleType
 from typing import Union
 
 from atc.configurator.configurator import Configurator
+from atc.schema_manager import SchemaManager
 from atc.spark import Spark
 from atc.sql import BaseExecutor
 
@@ -34,6 +35,11 @@ class SqlExecutor:
             exclude_pattern = exclude_pattern.replace("*", ".*")
 
         replacements = Configurator().get_all_details()
+        schema_replacements = {
+            f"{k}_schema": v
+            for k, v in SchemaManager().get_all_spark_sql_schemas().items()
+        }
+        replacements = {**replacements, **schema_replacements}
 
         executor = self.server or Spark.get()
 
